@@ -1,8 +1,12 @@
 pub mod common;
 pub mod mpmc;
 pub mod option;
+pub mod ring;
 pub mod spsc;
+pub mod vec;
 
 pub use mpmc::Mpmc;
 pub use option::AtomicOption;
+pub use ring::AtomicRing;
 pub use spsc::Spsc;
+pub use vec::AtomicVec;
